| round_preserve_sum | R Documentation |
Rounds a vector of numbers while preserving the sum of them.
round_preserve_sum(x, digits = 0)
x |
A numeric vector. |
digits |
The number of digits to take in account in the rounding process. |
round_preserve_sum returns y with round vector.
sum(c(0.333, 0.333, 0.334))
round(c(0.333, 0.333, 0.334), 2)
sum(round(c(0.333, 0.333, 0.334), 2))
round_preserve_sum(c(0.333, 0.333, 0.334), 2)
sum(round_preserve_sum(c(0.333, 0.333, 0.334), 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.